Hello community,

here is the log from the commit of package QtPass for openSUSE:Factory checked 
in at 2019-10-31 18:18:42
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Comparing /work/SRC/openSUSE:Factory/QtPass (Old)
 and      /work/SRC/openSUSE:Factory/.QtPass.new.2990 (New)
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Package is "QtPass"

Thu Oct 31 18:18:42 2019 rev:2 rq:744200 version:1.3.2

Changes:
--------
--- /work/SRC/openSUSE:Factory/QtPass/QtPass.changes    2019-10-30 
14:42:47.617861707 +0100
+++ /work/SRC/openSUSE:Factory/.QtPass.new.2990/QtPass.changes  2019-10-31 
18:19:02.114245294 +0100
@@ -1,0 +2,10 @@
+Wed Oct  9 18:54:58 UTC 2019 - [email protected]
+
+- Update to 1.3.2
+  - Don't call QtPass::setup() from QtPass class constructor #482
+     fixes first run issues #485, #481, #466, #423 and #308
+  - Password window padding #484
+  - Buttons width on RHEL 8 #483
+  - Start minimized works again #471
+
+-------------------------------------------------------------------

Old:
----
  QtPass-1.3.1.tar.gz

New:
----
  QtPass-1.3.2.tar.gz

++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Other differences:
------------------
++++++ QtPass.spec ++++++
--- /var/tmp/diff_new_pack.D0N6Rw/_old  2019-10-31 18:19:03.686246922 +0100
+++ /var/tmp/diff_new_pack.D0N6Rw/_new  2019-10-31 18:19:03.694246930 +0100
@@ -17,7 +17,7 @@
 
 
 Name:           QtPass
-Version:        1.3.1
+Version:        1.3.2
 Release:        0
 Summary:        A multi-platform gui for pass
 License:        GPL-3.0-only

++++++ QtPass-1.3.1.tar.gz -> QtPass-1.3.2.tar.gz ++++++
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/QtPass-1.3.1/CHANGELOG.md 
new/QtPass-1.3.2/CHANGELOG.md
--- old/QtPass-1.3.1/CHANGELOG.md       2019-10-01 16:04:06.000000000 +0200
+++ new/QtPass-1.3.2/CHANGELOG.md       2019-10-09 15:49:59.000000000 +0200
@@ -2,7 +2,31 @@
 
 ## [Unreleased](https://github.com/IJHack/QtPass/tree/HEAD)
 
-[Full Changelog](https://github.com/IJHack/QtPass/compare/v1.3.0...HEAD)
+[Full Changelog](https://github.com/IJHack/QtPass/compare/v1.3.1...HEAD)
+
+**Fixed bugs:**
+
+- QtPass could not run on Windows7 thin 
[\#485](https://github.com/IJHack/QtPass/issues/485)
+- Segfault on application startup \(macos\) 
[\#481](https://github.com/IJHack/QtPass/issues/481)
+- Application crashes on empty password store 
[\#466](https://github.com/IJHack/QtPass/issues/466)
+- App is completely broken [\#423](https://github.com/IJHack/QtPass/issues/423)
+
+**Closed issues:**
+
+- Edit window on Gnome has no padding around 
[\#484](https://github.com/IJHack/QtPass/issues/484)
+- Buttons width on RHEL 8 [\#483](https://github.com/IJHack/QtPass/issues/483)
+- `Start minimized' no longer works 
[\#471](https://github.com/IJHack/QtPass/issues/471)
+- Editor doesn't wait for PGP key to decrypt 
[\#470](https://github.com/IJHack/QtPass/issues/470)
+- v1.3.0 Data Not Showing [\#465](https://github.com/IJHack/QtPass/issues/465)
+- Hangs on MacOS after Security Update 2019-003 10.12.6 
[\#461](https://github.com/IJHack/QtPass/issues/461)
+- No public key [\#308](https://github.com/IJHack/QtPass/issues/308)
+
+**Merged pull requests:**
+
+- Don't call QtPass::setup\(\) from QtPass class constructor \(should fix 
\#466\) [\#482](https://github.com/IJHack/QtPass/pull/482) 
([maciejsszmigiero](https://github.com/maciejsszmigiero))
+
+## [v1.3.1](https://github.com/IJHack/QtPass/tree/v1.3.1) (2019-10-01)
+[Full Changelog](https://github.com/IJHack/QtPass/compare/v1.3.0...v1.3.1)
 
 **Implemented enhancements:**
 
@@ -112,6 +136,7 @@
 
 **Implemented enhancements:**
 
+- Feedback on copy button use 
[\#229](https://github.com/IJHack/QtPass/issues/229)
 - Cleaning \#includes [\#364](https://github.com/IJHack/QtPass/pull/364) 
([FiloSpaTeam](https://github.com/FiloSpaTeam))
 
 **Fixed bugs:**
@@ -140,6 +165,7 @@
 - No icon on MacOS [\#333](https://github.com/IJHack/QtPass/issues/333)
 - Font and spacing used for URL links on right in main window absurdly large 
[\#329](https://github.com/IJHack/QtPass/issues/329)
 - QtPass don't display all lines with templates 
[\#273](https://github.com/IJHack/QtPass/issues/273)
+- Double-clicking might open previous entry instead of one double-clicked on 
[\#243](https://github.com/IJHack/QtPass/issues/243)
 
 **Merged pull requests:**
 
@@ -153,13 +179,11 @@
 - Removed comment out \#includes 
[\#365](https://github.com/IJHack/QtPass/pull/365) 
([FiloSpaTeam](https://github.com/FiloSpaTeam))
 - fix for \#300 [\#363](https://github.com/IJHack/QtPass/pull/363) 
([FiloSpaTeam](https://github.com/FiloSpaTeam))
 - Translated all missing content to Italian, created Release of transla… 
[\#361](https://github.com/IJHack/QtPass/pull/361) 
([FiloSpaTeam](https://github.com/FiloSpaTeam))
-- Refactoring [\#360](https://github.com/IJHack/QtPass/pull/360) 
([lukedirtwalker](https://github.com/lukedirtwalker))
 - Display all fields when using template setting, fixes \#273 
[\#358](https://github.com/IJHack/QtPass/pull/358) 
([lukedirtwalker](https://github.com/lukedirtwalker))
 - Update CONTRIBUTING.md [\#354](https://github.com/IJHack/QtPass/pull/354) 
([5bentz](https://github.com/5bentz))
 - Add two entries in FAQ about the language 
[\#353](https://github.com/IJHack/QtPass/pull/353) 
([5bentz](https://github.com/5bentz))
 - Fix typo in french translation 
[\#349](https://github.com/IJHack/QtPass/pull/349) 
([babolivier](https://github.com/babolivier))
 - New scroll bar on large files 
[\#347](https://github.com/IJHack/QtPass/pull/347) 
([destanyol](https://github.com/destanyol))
-- Fix nested template argument list compile error 
[\#346](https://github.com/IJHack/QtPass/pull/346) 
([martinburchell](https://github.com/martinburchell))
 - Honor PREFIX during tests install 
[\#345](https://github.com/IJHack/QtPass/pull/345) 
([SpiderX](https://github.com/SpiderX))
 
 ## [v1.2.1](https://github.com/IJHack/QtPass/tree/v1.2.1) (2018-01-04)
@@ -220,11 +244,12 @@
 - Refactoring: removal of lastDecrypt 
[\#256](https://github.com/IJHack/QtPass/issues/256)
 - Pass environment not set-up correctly 
[\#250](https://github.com/IJHack/QtPass/issues/250)
 - Make fails - std c++11 not set 
[\#244](https://github.com/IJHack/QtPass/issues/244)
-- Double-clicking might open previous entry instead of one double-clicked on 
[\#243](https://github.com/IJHack/QtPass/issues/243)
 - Clean up ConfigDialog [\#235](https://github.com/IJHack/QtPass/issues/235)
 
 **Merged pull requests:**
 
+- Refactoring [\#360](https://github.com/IJHack/QtPass/pull/360) 
([lukedirtwalker](https://github.com/lukedirtwalker))
+- Fix nested template argument list compile error 
[\#346](https://github.com/IJHack/QtPass/pull/346) 
([martinburchell](https://github.com/martinburchell))
 - Extract static library and separate main function 
[\#324](https://github.com/IJHack/QtPass/pull/324) 
([tezeb](https://github.com/tezeb))
 - galego actualizado [\#323](https://github.com/IJHack/QtPass/pull/323) 
([xmgz](https://github.com/xmgz))
 - Add sftp, ftps, webdav and webdavs as supported links 
[\#322](https://github.com/IJHack/QtPass/pull/322) 
([cgonzalez](https://github.com/cgonzalez))
@@ -249,7 +274,6 @@
 
 **Implemented enhancements:**
 
-- Feedback on copy button use 
[\#229](https://github.com/IJHack/QtPass/issues/229)
 - Clickable url's + open in default browser 
[\#226](https://github.com/IJHack/QtPass/issues/226)
 - Deselecting password re-opens the file  
[\#221](https://github.com/IJHack/QtPass/issues/221)
 - Copy password button should include tooltip to say why, when disabled 
[\#214](https://github.com/IJHack/QtPass/issues/214)
@@ -339,7 +363,6 @@
 
 - Signed releases [\#186](https://github.com/IJHack/QtPass/issues/186)
 - Why it's not listed in wikipedia.org/wiki/List\_of\_password\_managers ? 
[\#164](https://github.com/IJHack/QtPass/issues/164)
-- "gpg-agent: command get\_passphrase failed: No such file or directory" 
[\#156](https://github.com/IJHack/QtPass/issues/156)
 - Bitdefender blocks installation and quarantines the .exe and .ink 
[\#138](https://github.com/IJHack/QtPass/issues/138)
 
 **Merged pull requests:**
@@ -376,6 +399,7 @@
 **Closed issues:**
 
 - gpg: decryption failed: No secret key 
[\#179](https://github.com/IJHack/QtPass/issues/179)
+- "gpg-agent: command get\_passphrase failed: No such file or directory" 
[\#156](https://github.com/IJHack/QtPass/issues/156)
 
 **Merged pull requests:**
 
@@ -537,7 +561,6 @@
 - Issue 86 clear panel [\#87](https://github.com/IJHack/QtPass/pull/87) 
([karlgrz](https://github.com/karlgrz))
 - Update FAQ for Yubikey NEO helper in .bashrc for Ubuntu 
[\#80](https://github.com/IJHack/QtPass/pull/80) 
([karlgrz](https://github.com/karlgrz))
 - \[WIP\] Call 'pass git init' on creation of password-store when useGit 
[\#78](https://github.com/IJHack/QtPass/pull/78) 
([dennisdegreef](https://github.com/dennisdegreef))
-- Support for editing .gpg-id via GUI with public keyring list. 
[\#23](https://github.com/IJHack/QtPass/pull/23) 
([rdoeffinger](https://github.com/rdoeffinger))
 
 ## [v1.0.0](https://github.com/IJHack/QtPass/tree/v1.0.0) (2015-08-01)
 [Full Changelog](https://github.com/IJHack/QtPass/compare/v0.9.2...v1.0.0)
@@ -584,6 +607,10 @@
 - Remember window size and vertical pane width 
[\#59](https://github.com/IJHack/QtPass/issues/59)
 - Multiline Editing [\#34](https://github.com/IJHack/QtPass/issues/34)
 
+**Merged pull requests:**
+
+- To make building successfull wi Desktop Qt 5.4.0 MSVC2012 OpenGL 32bit 
[\#67](https://github.com/IJHack/QtPass/pull/67) 
([annejan](https://github.com/annejan))
+
 ## [v0.8.5.1](https://github.com/IJHack/QtPass/tree/v0.8.5.1) (2015-07-08)
 [Full Changelog](https://github.com/IJHack/QtPass/compare/v0.8.5...v0.8.5.1)
 
@@ -658,7 +685,6 @@
 
 **Merged pull requests:**
 
-- To make building successfull wi Desktop Qt 5.4.0 MSVC2012 OpenGL 32bit 
[\#67](https://github.com/IJHack/QtPass/pull/67) 
([annejan](https://github.com/annejan))
 - SingleApplication per user and leading newline removed from output 
[\#44](https://github.com/IJHack/QtPass/pull/44) 
([annejan](https://github.com/annejan))
 - User filtering and many fixes 
[\#42](https://github.com/IJHack/QtPass/pull/42) 
([annejan](https://github.com/annejan))
 - Re-enable Windows WebDAV support. 
[\#37](https://github.com/IJHack/QtPass/pull/37) 
([rdoeffinger](https://github.com/rdoeffinger))
@@ -667,6 +693,7 @@
 - Add nosingleapp config. [\#27](https://github.com/IJHack/QtPass/pull/27) 
([rdoeffinger](https://github.com/rdoeffinger))
 - Add Makefile with commands to make a binary release zip file. 
[\#25](https://github.com/IJHack/QtPass/pull/25) 
([rdoeffinger](https://github.com/rdoeffinger))
 - Start process only after we finished disabling UI elements etc. 
[\#24](https://github.com/IJHack/QtPass/pull/24) 
([rdoeffinger](https://github.com/rdoeffinger))
+- Support for editing .gpg-id via GUI with public keyring list. 
[\#23](https://github.com/IJHack/QtPass/pull/23) 
([rdoeffinger](https://github.com/rdoeffinger))
 - More proper support for subdirectories. 
[\#22](https://github.com/IJHack/QtPass/pull/22) 
([rdoeffinger](https://github.com/rdoeffinger))
 - Russian translation \(+typo fixed\) 
[\#20](https://github.com/IJHack/QtPass/pull/20) 
([mexus](https://github.com/mexus))
 - Windows-related fixes. [\#17](https://github.com/IJHack/QtPass/pull/17) 
([rdoeffinger](https://github.com/rdoeffinger))
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/QtPass-1.3.1/Doxyfile new/QtPass-1.3.2/Doxyfile
--- old/QtPass-1.3.1/Doxyfile   2019-10-01 16:04:06.000000000 +0200
+++ new/QtPass-1.3.2/Doxyfile   2019-10-09 15:49:59.000000000 +0200
@@ -38,7 +38,7 @@
 # could be handy for archiving the generated documentation or if some version
 # control system is used.
 
-PROJECT_NUMBER         = 1.3.1
+PROJECT_NUMBER         = 1.3.2
 
 # Using the PROJECT_BRIEF tag one can provide an optional one line description
 # for a project that appears at the top of each page and should give viewer a
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/QtPass-1.3.1/README.md new/QtPass-1.3.2/README.md
--- old/QtPass-1.3.1/README.md  2019-10-01 16:04:06.000000000 +0200
+++ new/QtPass-1.3.2/README.md  2019-10-09 15:49:59.000000000 +0200
@@ -154,8 +154,8 @@
 
 View official GNU site <http://www.gnu.org/licenses/gpl.html>.
 
-[![OSI](http://opensource.org/trademarks/opensource/OSI-Approved-License-100x137.png)](http://opensource.org/licenses/mit-license.php)
+[![OSI](http://opensource.org/trademarks/opensource/OSI-Approved-License-100x137.png)](https://opensource.org/licenses/GPL-3.0)
 
-[View the Open Source Initiative 
site.](http://opensource.org/licenses/mit-license.php)
+[View the Open Source Initiative 
site.](https://opensource.org/licenses/GPL-3.0)
 
 [![FOSSA 
Status](https://app.fossa.io/api/projects/git%2Bgithub.com%2FIJHack%2FQtPass.svg?type=large)](https://app.fossa.io/projects/git%2Bgithub.com%2FIJHack%2FQtPass?ref=badge_large)
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/QtPass-1.3.1/localization/localization_nl_BE.ts 
new/QtPass-1.3.2/localization/localization_nl_BE.ts
--- old/QtPass-1.3.1/localization/localization_nl_BE.ts 2019-10-01 
16:04:06.000000000 +0200
+++ new/QtPass-1.3.2/localization/localization_nl_BE.ts 2019-10-09 
15:49:59.000000000 +0200
@@ -576,7 +576,7 @@
     </message>
     <message>
         <location/>
-        <location filename="../src/mainwindow.cpp" line="+897"/>
+        <location filename="../src/mainwindow.cpp" line="+899"/>
         <source>Add password</source>
         <translation type="unfinished"></translation>
     </message>
@@ -599,7 +599,7 @@
     </message>
     <message>
         <location/>
-        <location filename="../src/mainwindow.cpp" line="+19"/>
+        <location filename="../src/mainwindow.cpp" line="+21"/>
         <source>Delete</source>
         <translation type="unfinished"></translation>
     </message>
@@ -640,7 +640,7 @@
     </message>
     <message>
         <location/>
-        <location filename="../src/mainwindow.cpp" line="-25"/>
+        <location filename="../src/mainwindow.cpp" line="-27"/>
         <source>Users</source>
         <translation type="unfinished"></translation>
     </message>
@@ -677,12 +677,12 @@
     </message>
     <message>
         <location line="+4"/>
-        <location line="+703"/>
+        <location line="+699"/>
         <source>Password</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-677"/>
+        <location line="-673"/>
         <source>OTP Code</source>
         <translation type="unfinished"></translation>
     </message>
@@ -698,12 +698,12 @@
     </message>
     <message>
         <location line="+97"/>
-        <location line="+359"/>
+        <location line="+361"/>
         <source>New file</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-358"/>
+        <location line="-360"/>
         <source>New password file: 
 (Will be placed in %1 )</source>
         <translation type="unfinished"></translation>
@@ -749,29 +749,29 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+3"/>
+        <location line="+4"/>
         <source>Rename password</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+41"/>
+        <location line="+42"/>
         <source>New Folder: 
 (Will be placed in %1 )</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+20"/>
-        <location line="+33"/>
+        <location line="+21"/>
+        <location line="+29"/>
         <source>Rename file</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-32"/>
+        <location line="-29"/>
         <source>Rename Folder To: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+33"/>
+        <location line="+29"/>
         <source>Rename File To: </source>
         <translation type="unfinished"></translation>
     </message>
@@ -840,7 +840,7 @@
 <context>
     <name>QtPass</name>
     <message>
-        <location filename="../src/qtpass.cpp" line="+143"/>
+        <location filename="../src/qtpass.cpp" line="+139"/>
         <source>Generating GPG key pair</source>
         <translation type="unfinished"></translation>
     </message>
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/QtPass-1.3.1/localization/localization_nl_NL.ts 
new/QtPass-1.3.2/localization/localization_nl_NL.ts
--- old/QtPass-1.3.1/localization/localization_nl_NL.ts 2019-10-01 
16:04:06.000000000 +0200
+++ new/QtPass-1.3.2/localization/localization_nl_NL.ts 2019-10-09 
15:49:59.000000000 +0200
@@ -576,7 +576,7 @@
     </message>
     <message>
         <location/>
-        <location filename="../src/mainwindow.cpp" line="+897"/>
+        <location filename="../src/mainwindow.cpp" line="+899"/>
         <source>Add password</source>
         <translation type="unfinished"></translation>
     </message>
@@ -599,7 +599,7 @@
     </message>
     <message>
         <location/>
-        <location filename="../src/mainwindow.cpp" line="+19"/>
+        <location filename="../src/mainwindow.cpp" line="+21"/>
         <source>Delete</source>
         <translation type="unfinished"></translation>
     </message>
@@ -640,7 +640,7 @@
     </message>
     <message>
         <location/>
-        <location filename="../src/mainwindow.cpp" line="-25"/>
+        <location filename="../src/mainwindow.cpp" line="-27"/>
         <source>Users</source>
         <translation type="unfinished"></translation>
     </message>
@@ -677,12 +677,12 @@
     </message>
     <message>
         <location line="+4"/>
-        <location line="+703"/>
+        <location line="+699"/>
         <source>Password</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-677"/>
+        <location line="-673"/>
         <source>OTP Code</source>
         <translation type="unfinished"></translation>
     </message>
@@ -698,12 +698,12 @@
     </message>
     <message>
         <location line="+97"/>
-        <location line="+359"/>
+        <location line="+361"/>
         <source>New file</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-358"/>
+        <location line="-360"/>
         <source>New password file: 
 (Will be placed in %1 )</source>
         <translation type="unfinished"></translation>
@@ -749,29 +749,29 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+3"/>
+        <location line="+4"/>
         <source>Rename password</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+41"/>
+        <location line="+42"/>
         <source>New Folder: 
 (Will be placed in %1 )</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+20"/>
-        <location line="+33"/>
+        <location line="+21"/>
+        <location line="+29"/>
         <source>Rename file</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-32"/>
+        <location line="-29"/>
         <source>Rename Folder To: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+33"/>
+        <location line="+29"/>
         <source>Rename File To: </source>
         <translation type="unfinished"></translation>
     </message>
@@ -840,7 +840,7 @@
 <context>
     <name>QtPass</name>
     <message>
-        <location filename="../src/qtpass.cpp" line="+143"/>
+        <location filename="../src/qtpass.cpp" line="+139"/>
         <source>Generating GPG key pair</source>
         <translation type="unfinished"></translation>
     </message>
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/QtPass-1.3.1/qtpass.iss new/QtPass-1.3.2/qtpass.iss
--- old/QtPass-1.3.1/qtpass.iss 2019-10-01 16:04:06.000000000 +0200
+++ new/QtPass-1.3.2/qtpass.iss 2019-10-09 15:49:59.000000000 +0200
@@ -2,7 +2,7 @@
 ; SEE THE DOCUMENTATION FOR DETAILS ON CREATING INNO SETUP SCRIPT FILES!
 
 #define MyAppName "QtPass"
-#define MyAppVersion "1.3.1"
+#define MyAppVersion "1.3.2"   
 #define MyAppPublisher "IJhack"
 #define MyAppURL "https://qtpass.org/";
 #define MyAppExeName "qtpass.exe"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/QtPass-1.3.1/qtpass.plist 
new/QtPass-1.3.2/qtpass.plist
--- old/QtPass-1.3.1/qtpass.plist       2019-10-01 16:04:06.000000000 +0200
+++ new/QtPass-1.3.2/qtpass.plist       2019-10-09 15:49:59.000000000 +0200
@@ -15,7 +15,7 @@
        <key>CFBundlePackageType</key>
        <string>APPL</string>
        <key>CFBundleShortVersionString</key>
-       <string>1.3.1</string>
+       <string>1.3.2</string>
        <key>CFBundleSignature</key>
        <string>@TYPEINFO@</string>
        <key>NOTE</key>
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/QtPass-1.3.1/qtpass.pri new/QtPass-1.3.2/qtpass.pri
--- old/QtPass-1.3.1/qtpass.pri 2019-10-01 16:04:06.000000000 +0200
+++ new/QtPass-1.3.2/qtpass.pri 2019-10-09 15:49:59.000000000 +0200
@@ -1,4 +1,4 @@
-VERSION    = 1.3.1
+VERSION    = 1.3.2
 
 CONFIG(coverage) {
        QMAKE_LFLAGS += --coverage
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/QtPass-1.3.1/qtpass.spec new/QtPass-1.3.2/qtpass.spec
--- old/QtPass-1.3.1/qtpass.spec        2019-10-01 16:04:06.000000000 +0200
+++ new/QtPass-1.3.2/qtpass.spec        2019-10-09 15:49:59.000000000 +0200
@@ -7,7 +7,7 @@
 # This should probably be part of a release process.
 
 Name: qtpass           
-Version: 1.3.1
+Version: 1.3.2
 Release: 2%{?dist}
 Summary: QtPass is a multi-platform GUI for pass, the standard unix password 
manager.  
 License: GPLv3
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/QtPass-1.3.1/src/filecontent.cpp 
new/QtPass-1.3.2/src/filecontent.cpp
--- old/QtPass-1.3.1/src/filecontent.cpp        2019-10-01 16:04:06.000000000 
+0200
+++ new/QtPass-1.3.2/src/filecontent.cpp        2019-10-09 15:49:59.000000000 
+0200
@@ -1,7 +1,7 @@
 #include "filecontent.h"
 
 static bool isLineHidden(const QString &line) {
-       return line.startsWith("otpauth://", Qt::CaseInsensitive);
+  return line.startsWith("otpauth://", Qt::CaseInsensitive);
 }
 
 FileContent FileContent::parse(const QString &fileContent,
@@ -48,7 +48,8 @@
                          const QString &remainingData,
                          const QString &remainingDataDisplay)
     : password(password), namedValues(namedValues),
-      remainingData(remainingData), remainingDataDisplay(remainingDataDisplay) 
{}
+      remainingData(remainingData), remainingDataDisplay(remainingDataDisplay) 
{
+}
 
 NamedValues::NamedValues() : QList() {}
 
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/QtPass-1.3.1/src/filecontent.h 
new/QtPass-1.3.2/src/filecontent.h
--- old/QtPass-1.3.1/src/filecontent.h  2019-10-01 16:04:06.000000000 +0200
+++ new/QtPass-1.3.2/src/filecontent.h  2019-10-09 15:49:59.000000000 +0200
@@ -69,7 +69,8 @@
 
 private:
   FileContent(const QString &password, const NamedValues &namedValues,
-              const QString &remainingData, const QString 
&remainingDataDisplay);
+              const QString &remainingData,
+              const QString &remainingDataDisplay);
 
   QString password;
   NamedValues namedValues;
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/QtPass-1.3.1/src/mainwindow.cpp 
new/QtPass-1.3.2/src/mainwindow.cpp
--- old/QtPass-1.3.1/src/mainwindow.cpp 2019-10-01 16:04:06.000000000 +0200
+++ new/QtPass-1.3.2/src/mainwindow.cpp 2019-10-09 15:49:59.000000000 +0200
@@ -44,8 +44,7 @@
 #endif
   ui->setupUi(this);
 
-  m_qtPass = new QtPass();
-  m_qtPass->setMainWindow(this);
+  m_qtPass = new QtPass(this);
 
   // register shortcut ctrl/cmd + Q to close the main window
   new QShortcut(QKeySequence(Qt::CTRL + Qt::Key_Q), this, SLOT(close()));
@@ -72,8 +71,7 @@
   selectionModel.reset(new QItemSelectionModel(&proxyModel));
 
   ui->treeView->setModel(&proxyModel);
-  ui->treeView->setRootIndex(
-      proxyModel.mapFromSource(rootDir));
+  ui->treeView->setRootIndex(proxyModel.mapFromSource(rootDir));
   ui->treeView->setColumnHidden(1, true);
   ui->treeView->setColumnHidden(2, true);
   ui->treeView->setColumnHidden(3, true);
@@ -119,6 +117,10 @@
   QTimer::singleShot(10, this, SLOT(focusInput()));
 
   ui->lineEdit->setText(searchText);
+
+  if (!m_qtPass->init())
+    // no working config so this should just quit
+    QApplication::quit();
 }
 
 MainWindow::~MainWindow() { delete m_qtPass; }
@@ -481,13 +483,13 @@
 
   if (QtPassSettings::isUseTrayIcon() && tray == nullptr) {
     initTrayIcon();
-    if (m_qtPass->isFreshStart() && QtPassSettings::isStartMinimized()) {
+    if (QtPassSettings::isStartMinimized()) {
       // since we are still in constructor, can't directly hide
       QTimer::singleShot(10, this, SLOT(hide()));
     }
-  } /*else if (!QtPassSettings::isUseTrayIcon() && tray != NULL) {
+  } else if (!QtPassSettings::isUseTrayIcon() && tray != nullptr) {
     destroyTrayIcon();
-  }*/
+  }
 }
 
 /**
@@ -915,10 +917,12 @@
     contextMenu.addSeparator();
     if (fileOrFolder.isDir()) {
       QAction *renameFolder = contextMenu.addAction(tr("Rename folder"));
-      connect(renameFolder, &QAction::triggered, this, 
&MainWindow::renameFolder);
+      connect(renameFolder, &QAction::triggered, this,
+              &MainWindow::renameFolder);
     } else if (fileOrFolder.isFile()) {
       QAction *renamePassword = contextMenu.addAction(tr("Rename password"));
-      connect(renamePassword, &QAction::triggered, this, 
&MainWindow::renamePassword);
+      connect(renamePassword, &QAction::triggered, this,
+              &MainWindow::renamePassword);
     }
     QAction *deleteItem = contextMenu.addAction(tr("Delete"));
     connect(deleteItem, &QAction::triggered, this, &MainWindow::onDelete);
@@ -975,14 +979,12 @@
  */
 void MainWindow::renameFolder() {
   bool ok;
-  QString srcDir = QDir::cleanPath(Util::getDir(ui->treeView->currentIndex(), 
false, model, proxyModel));
+  QString srcDir = QDir::cleanPath(
+      Util::getDir(ui->treeView->currentIndex(), false, model, proxyModel));
   QString srcDirName = QDir(srcDir).dirName();
   QString newName =
-      QInputDialog::getText(this, tr("Rename file"),
-                            tr("Rename Folder To: "),
-                            QLineEdit::Normal,
-                            srcDirName,
-                            &ok);
+      QInputDialog::getText(this, tr("Rename file"), tr("Rename Folder To: "),
+                            QLineEdit::Normal, srcDirName, &ok);
   if (!ok || newName.isEmpty())
     return;
   QString destDir = srcDir;
@@ -990,7 +992,6 @@
   QtPassSettings::getPass()->Move(srcDir, destDir);
 }
 
-
 /**
  * @brief MainWindow::editPassword read password and open edit window via
  * MainWindow::onEdit()
@@ -1011,11 +1012,8 @@
   QString file = getFile(ui->treeView->currentIndex(), false);
   QString fileName = QFileInfo(file).baseName();
   QString newName =
-      QInputDialog::getText(this, tr("Rename file"),
-                            tr("Rename File To: "),
-                            QLineEdit::Normal,
-                            fileName,
-                            &ok);
+      QInputDialog::getText(this, tr("Rename file"), tr("Rename File To: "),
+                            QLineEdit::Normal, fileName, &ok);
   if (!ok || newName.isEmpty())
     return;
   QString newFile = file;
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/QtPass-1.3.1/src/mainwindow.ui 
new/QtPass-1.3.2/src/mainwindow.ui
--- old/QtPass-1.3.1/src/mainwindow.ui  2019-10-01 16:04:06.000000000 +0200
+++ new/QtPass-1.3.2/src/mainwindow.ui  2019-10-09 15:49:59.000000000 +0200
@@ -284,7 +284,7 @@
     <bool>false</bool>
    </property>
    <property name="toolButtonStyle">
-    <enum>Qt::ToolButtonFollowStyle</enum>
+    <enum>Qt::ToolButtonIconOnly</enum>
    </property>
    <attribute name="toolBarArea">
     <enum>TopToolBarArea</enum>
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/QtPass-1.3.1/src/qtpass.h 
new/QtPass-1.3.2/src/qtpass.h
--- old/QtPass-1.3.1/src/qtpass.h       2019-10-01 16:04:06.000000000 +0200
+++ new/QtPass-1.3.2/src/qtpass.h       2019-10-09 15:49:59.000000000 +0200
@@ -11,10 +11,10 @@
   Q_OBJECT
 
 public:
-  QtPass();
+  QtPass(MainWindow *mainWindow);
   ~QtPass();
 
-  void setMainWindow(MainWindow *mW);
+  bool init();
   void setClippedText(const QString &, const QString &p_output = QString());
   void clearClippedText();
   void setClipboardTimer();
@@ -30,7 +30,7 @@
   QString clippedText;
   bool freshStart;
 
-  bool setup();
+  void setMainWindow();
   void connectPassSignalHandlers(Pass *pass);
   void mountWebDav();
 


Reply via email to
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/QtPass-1.3.1/src/passworddialog.h 
new/QtPass-1.3.2/src/passworddialog.h
--- old/QtPass-1.3.1/src/passworddialog.h       2019-10-01 16:04:06.000000000 
+0200
+++ new/QtPass-1.3.2/src/passworddialog.h       2019-10-09 15:49:59.000000000 
+0200
@@ -23,7 +23,8 @@
 public:
   explicit PasswordDialog(const PasswordConfiguration &passConfig,
                           QWidget *parent = nullptr);
-  PasswordDialog(const QString &file, const bool &isNew, QWidget *parent = 
nullptr);
+  PasswordDialog(const QString &file, const bool &isNew,
+                 QWidget *parent = nullptr);
   ~PasswordDialog();
 
   /*! Sets content in the password field in the interface.
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/QtPass-1.3.1/src/passworddialog.ui 
new/QtPass-1.3.2/src/passworddialog.ui
--- old/QtPass-1.3.1/src/passworddialog.ui      2019-10-01 16:04:06.000000000 
+0200
+++ new/QtPass-1.3.2/src/passworddialog.ui      2019-10-09 15:49:59.000000000 
+0200
@@ -15,16 +15,16 @@
   </property>
   <layout class="QVBoxLayout" name="verticalLayout_2" stretch="0">
    <property name="leftMargin">
-    <number>0</number>
+    <number>6</number>
    </property>
    <property name="topMargin">
     <number>6</number>
    </property>
    <property name="rightMargin">
-    <number>0</number>
+    <number>6</number>
    </property>
    <property name="bottomMargin">
-    <number>0</number>
+    <number>6</number>
    </property>
    <item>
     <widget class="QWidget" name="widget" native="true">
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/QtPass-1.3.1/src/qtpass.cpp 
new/QtPass-1.3.2/src/qtpass.cpp
--- old/QtPass-1.3.1/src/qtpass.cpp     2019-10-01 16:04:06.000000000 +0200
+++ new/QtPass-1.3.2/src/qtpass.cpp     2019-10-09 15:49:59.000000000 +0200
@@ -22,13 +22,8 @@
 #include "debughelper.h"
 #endif
 
-QtPass::QtPass() : clippedText(QString()), freshStart(true) {
-  if (!setup()) {
-    // no working config so this should quit without config anything
-    QApplication::quit();
-    {}
-  }
-
+QtPass::QtPass(MainWindow *mainWindow)
+    : m_mainWindow(mainWindow), clippedText(QString()), freshStart(true) {
   setClipboardTimer();
   clearClipboardTimer.setSingleShot(true);
   connect(&clearClipboardTimer, SIGNAL(timeout()), this,
@@ -36,6 +31,8 @@
 
   QObject::connect(qApp, &QApplication::aboutToQuit, this,
                    &QtPass::clearClipboard);
+
+  setMainWindow();
 }
 
 /**
@@ -55,10 +52,10 @@
 }
 
 /**
  * @brief QtPass::setup make sure we are ready to go as soon as
  * possible
  */
-bool QtPass::setup() {
+bool QtPass::init() {
   QString passStore = QtPassSettings::getPassStore(Util::findPasswordStore());
   QtPassSettings::setPassStore(passStore);
 
@@ -111,8 +108,7 @@
   return true;
 }
 
-void QtPass::setMainWindow(MainWindow *mW) {
-  m_mainWindow = mW;
+void QtPass::setMainWindow(void) {
   m_mainWindow->restoreWindow();
 
   fusedav.setParent(m_mainWindow);
@@ -55,10 +52,10 @@
 
 /**
- * @brief QtPass::setup make sure we are ready to go as soon as
+ * @brief QtPass::init make sure we are ready to go as soon as
  * possible
  */